import 'package:flutter/material.dart';

enum AnimationType {
  normal, // para ver lo q esta disponible
  fadeIn,
}

class RouteTransitions {
  final BuildContext context;
  final Widget child;
  final AnimationType animation;
  final Duration duration;
  final bool replacement;

  RouteTransitions({
    required this.context,
    required this.child,
    this.replacement = false,
    this.animation = AnimationType.normal,
    this.duration = const Duration(milliseconds: 300),
  }) {
    switch (animation) {
      case AnimationType.normal:
        _normalTransition();
        break;

      case AnimationType.fadeIn:
        _fadeInTransition();
        break;
      default:
    }
  }

  
  void _pushPage(Route route) => Navigator.push(context, route);

    //metodo que destruye la pagina anterior, por lo q no se podra volver
  void _pushReplacementPage(Route route) =>
      Navigator.pushReplacement(context, route);

      //Metodo de transicion normal
  void _normalTransition() {
    final route = MaterialPageRoute(builder: (_) => child);
    (replacement) ? _pushReplacementPage(route) : _pushPage(route);
  }

//Personalizacion de la animación
  void _fadeInTransition() {
    final route = PageRouteBuilder(
        pageBuilder: (_, __, ___) =>
            child, // buildcontext, animacion1, animacion2
        transitionDuration: duration,
        transitionsBuilder: (_, animacion, __, child) {
          return FadeTransition(
            opacity: Tween<double>(begin: 0.0, end: 1.0).animate(
                CurvedAnimation(parent: animacion, curve: Curves.easeOut)),
            child: child,
          );
        });
      if (replacement) {
            Navigator.pushReplacement(context, route);
          } else {
            Navigator.push(context, route);
        }
  }
}
